/*******************************************************************************

EARNINGS AND SELF-EMPLOYMENT -- EWCS DATA
Fall 2023

Filename: 	01_Basics.do
Authors: 	Jorge Velilla
			Department of Economic Analysis
			MSc in Economics 2023-2024, University of Zaragoza (Spain)
________________________________________________________________________________

This file provides instructions to compute baseline sample preparation, summary
statistics of main variables, t-type tests and tabulates, baseline estimates, 
and export estimation results.

*******************************************************************************/

* 	Clear memory
clear all

*	Set working directory
cd "C:\Users\jveli\Desktop\2023_ClaseMaster_2023-24"


/*******************************************************************************
	Request data and make some adjustments:
		- Keep a given year or a given country
		- Delete variables
		- Redefine variables
		- Generate variables
		- Label variables
		- Order variables
		- Rename variables
*******************************************************************************/

*	Request data
use "Data/Sample.dta", clear

*	Keep Portugal, Italy, Greece, Spain
fre country
keep if country==8 | country==11 | country==7 | country==21

*	Redefine work hours (weekly to monthly)
replace hours = hours/7*30

*	Generate wages and log wages
generate wage 				= earnings/hours

*	Order variables
order id-earnings wage

*	Delete unwanted variables
drop employee earnings

*	Rename variables for simplicity
rename edu_primary 		edu1
rename edu_secondary 	edu2
rename edu_university	edu3
rename self_employed	selfemp
rename occu_isco081		occu
rename activity_nace10	act

*	Label variables					
label variable year 		"Year"
label variable country		"Country" 
label variable region 		"Region"
label variable male 		"Being male"
label variable age 			"Age"
label variable edu1 		"Primary education"
label variable edu2 		"Secondary education"
label variable edu3 		"University education"
label variable married 		"Being married"
label variable childnum 	"N. of children"
label variable selfemp 		"Self-employed worker"
label variable hours 		"Work hours per month"
label variable wage 		"Hourly wage"
label variable wlb_slim 	"Wellbeing indicator"
label variable occu			"Occupation - ISCO081"
label variable act			"Activity - NACE10"
label variable urban		"Urbanization level"

*	Generate country, year, occupation dummies
tabulate country, 	gen(ctry_)
tabulate year, 		gen(year_)
tabulate occu, 		gen(occu_)
tabulate act, 		gen(act_)


/*******************************************************************************
	Compute summary statistics and baseline tests
		- Compute sum stats table
		- Compute additional sum stats (frequencies, tables...)
		- Compute t-test p-values for differences between groups
*******************************************************************************/

*	Summary statistics of main variables, by country
*	- Full sample:
summarize 	age male edu1 edu2 edu3 hours wage selfemp 
*	- Portugal:
summarize 	age male edu1 edu2 edu3 hours wage selfemp if country==21
*	- Italy:
summarize 	age male edu1 edu2 edu3 hours wage selfemp if country==11
*	- Greece:
summarize 	age male edu1 edu2 edu3 hours wage selfemp if country==7
*	- Spain:
summarize 	age male edu1 edu2 edu3 hours wage selfemp if country==8

*	Tabulate observations by country
tabulate year

*	Summary statistics of main variables, by country and self-employment
*	- Portugal, self-employed:
summarize 	age male edu1 edu2 edu3 hours wage selfemp if country==21 & selfemp==1
*	- Portugal, employees:
summarize 	age male edu1 edu2 edu3 hours wage selfemp if country==21 & selfemp==0
*	- Italy, self-employed:
summarize 	age male edu1 edu2 edu3 hours wage selfemp if country==11 & selfemp==1
*	- Italy, employees:
summarize 	age male edu1 edu2 edu3 hours wage selfemp if country==11 & selfemp==0
*	- Greece, self-employed:
summarize 	age male edu1 edu2 edu3 hours wage selfemp if country==7 & selfemp==1
*	- Greece, employees:
summarize 	age male edu1 edu2 edu3 hours wage selfemp if country==7 & selfemp==0
*	- Spain, self-employed:
summarize 	age male edu1 edu2 edu3 hours wage selfemp if country==8 & selfemp==1
*	- Spain, employees:
summarize 	age male edu1 edu2 edu3 hours wage selfemp if country==8 & selfemp==0

*	Test for inequality in age, Univ education, wages, hours
*	- Portugal:
ttest age if country==21,	by(selfemp)
ttest male if country==21,	by(selfemp)
ttest edu3 if country==21,	by(selfemp)
ttest wage if country==21,	by(selfemp)
ttest hours if country==21, by(selfemp)
*	- Italy:
ttest age if country==11,	by(selfemp)
ttest male if country==11,	by(selfemp)
ttest edu3 if country==11,	by(selfemp)
ttest wage if country==11,	by(selfemp)
ttest hours if country==11, by(selfemp)
*	- Greece:
ttest age if country==7,	by(selfemp)
ttest male if country==7,	by(selfemp)
ttest edu3 if country==7,	by(selfemp)
ttest wage if country==7,	by(selfemp)
ttest hours if country==7, by(selfemp)
*	- Spain:
ttest age if country==8,	by(selfemp)
ttest male if country==8,	by(selfemp)
ttest edu3 if country==8,	by(selfemp)
ttest wage if country==8,	by(selfemp)
ttest hours if country==8, by(selfemp)


/*******************************************************************************
	Compute some figures
*******************************************************************************/

*	Density of wages but more paper-style
kdensity	wage if wage<50 & selfemp==0, lcolor(black) lpattern(solid) 	///
			addplot((kdensity wage if wage<50 & selfemp==1, 				///
					lcolor(black) lpattern(dash))) 							///
			ytitle(Density) xtitle(Wage) 									///
			ylabel(, angle(zero))											///
			legend(order(1 "Self-emp." 2 "Employees") ring(0) pos(2)) 		///
			scheme(s1mono) 													///
			title(,size(zero))			

*	Density of work hours
kdensity	hours if hours<200 & selfemp==0, lcolor(black) lpattern(solid) 	///
			addplot((kdensity hours if hours<200 & selfemp==1, 				///
					lcolor(black) lpattern(dash))) 							///
			ytitle(Density) xtitle(Hours) 									///
			ylabel(, angle(zero))											///
			legend(order(1 "Self-emp." 2 "Employees") ring(0) pos(2)) 		///
			scheme(s1mono) 													///
			title(,size(zero))			


/*******************************************************************************
	OLS estimates
		- Compute estimates
		- Export estimates
*******************************************************************************/

*	Baseline estimates
regress wage male age edu2 edu3 married childnum hours selfemp ctry_* occu_* act_*, robust
outreg2 using "Output/Baseline.xls", bdec(3) ctitle(Baseline) label se replace

*	Estimates on self-employed workers
regress wage male age edu2 edu3 married childnum selfemp hours ctry_* occu_* act_* if selfemp==1, robust
outreg2 using "Output/Baseline.xls", bdec(3) ctitle(Self-employed) label se append

*	Estimates on employees
regress wage male age edu2 edu3 married childnum selfemp hours ctry_* occu_* act_* if selfemp==0, robust
outreg2 using "Output/Baseline.xls", bdec(3) ctitle(Employees) label se append

*	Interactions
generate male_selfemp		= selfemp*male
generate age_selfemp		= selfemp*age
generate edu2_selfemp		= selfemp*edu2
generate edu3_selfemp		= selfemp*edu3
generate married_selfemp	= selfemp*married
generate childnum_selfemp	= selfemp*childnum
generate hours_selfemp		= selfemp*hours

*	Interaction estimates
regress wage male age edu2 edu3 married childnum hours selfemp male_selfemp ///
			 age_selfemp edu2_selfemp edu3_selfemp married_selfemp 			///
			 childnum_selfemp hours_selfemp ctry_* occu_* act_*, robust		
outreg2 using "Output/Baseline.xls", bdec(3) ctitle(Interactions) label se append


*** End of dofile